pub trait KeyLog:
Send
+ Sync
+ Debug {
// Required method
fn log(&self, label: &str, client_random: &[u8], secret: &[u8]);
}Expand description
Trait for receiving TLS session secrets.
Implementations are responsible for recording the label, client random, and secret triple in the NSS Key Log Format used by Wireshark and other tools.
Implementors must be Send + Sync + fmt::Debug.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".