oxitls-core — Pure-Rust TLS transport primitives.
This crate provides the foundational types used across the OxiTLS ecosystem: error types, TLS version and cipher suite enumerations, connection information, and trait definitions for TLS connectors/acceptors.
Re-exports
pub use alert::AlertDescription;pub use keylog::KeyLog;pub use keylog::KeyLogPolicy;pub use os_rng::OsRng;pub use stream_info::connection_info_from;
Modules
- alert
- TLS alert description codes (RFC 8446 6). TLS alert descriptions as defined in RFC 8446 6.
- config
- Generic TLS configuration introspection trait. Generic TLS configuration introspection trait.
- keylog
- Key-logging policy for TLS session secret export. Key-logging policy for TLS session secret export.
- os_rng
- OS-entropy CSPRNG adapter implementing the
rand_core0.6 traits required byrsa/ed25519-dalek/x25519-dalek(decoupled from the workspacerand/rand_core0.10). OS-entropy CSPRNG adapters (seeOsRng). - stream_
info - Helpers for extracting
ConnectionInfofrom a rustls connection state. Helper for extractingConnectionInfofrom a rustls connection state.
Structs
- Connection
Info - Information about a completed TLS connection.
- Connection
Info Builder - Fluent builder for
ConnectionInfo.
Enums
- Cipher
Suite - TLS cipher suite identifiers covering TLS 1.3 mandatory suites and commonly-used TLS 1.2 AEAD suites.
- TlsError
- Errors that can occur during TLS operations.
- TlsVersion
- TLS protocol version.
Traits
- TlsAcceptor
- Types that can accept inbound TLS connections.
- TlsConnector
- Types that can establish outbound TLS connections.
- TlsStream
Info - Trait for TLS streams that can expose post-handshake connection metadata.
- TlsStream
Trait - Trait alias for an async TLS stream.
Type Aliases
- TlsStream
- A boxed async stream that can be read from and written to.